Google Product Result

Press
/ to jump to the search box
Choose what you’re giving feedback on

- Delete

- See more
- Delete

See more
Report inappropriate predictions
Quick Settings
Choose what you’re giving feedback on
Or give
This item is no longer available

- Edit shopping preferences
- Report an issue

# About this page

Reviews aren’t verified by Google.
Aspercreme Lidocaine Pain Relief Roll-On
Something went wrong. Details failed to load.
Best price
Walmart
$8.98
Aspercreme Max Strength Topical Numbing Pain Reliever Roll-on Liquid, 4% Lidocaine, Odor Free, 2.5 fl oz, Size: Pack of 1
In stock online
4.3/5
·Delivery $6.99
·Free 90-day returns
Target
$11.69
Aspercreme Lidocaine with No Mess Applicator - 2.5 fl oz
In stock online
4.6/5
·Delivery between Sep 24 – 30 on orders $35+
·Free 90-day returns
Walgreens.com
$13.99
Aspercreme Lidocaine Pain Relief Roll-On Fragrance Free - 2.5 fl oz
In stock online
4.6/5
·Delivery $5.99
·Free 30-day returns
CVS Pharmacy
$14.49
Aspercreme Lidocaine Pain Relief Liquid Roll-On, 2.5 FL oz, Odorless | External Relief - 2.5 oz | CVS
In stock online
4.7/5
·Free delivery between Tue - Thu on orders $35+·Delivery between Tue - Thu $5.49
·60-day returns
HSA Store
$12.99
HSA-Eligible | Aspercreme Roll-On w/ 4% Lidocaine, 2.5 fl oz
In stock online
4.6/5
·Free delivery between Sep 23 – 30 on orders $50+·Delivery between Sep 23 – 30 $5.99
·30-day returns
FSA Store
$12.99
FSA-Eligible | Aspercreme Roll-On w/ 4% Lidocaine, 2.5 fl oz | FSA Store
In stock online
4.7/5
·Free delivery between Sep 23 – 30 on orders $50+·Delivery between Sep 23 – 30 $7.99
·30-day returns
HealthWarehouse.com
$12.06
10% off
$13
Aspercreme Maximum Strength Lidocaine No-Mess Roll-On 2.5 oz. (1-3 unit)
In stock online
10% off Generic Rx and OTC Products
Copy code GSHP
Copied
4.6/5
·Free delivery by Tue
·Free 90-day returns
OTC Superstore
$8.99
10% off
$9.99
Aspercreme Lidocaine No Mess Applicator 2.5 oz
In stock online
10% OFF Entire Purchase - No Minimum Purchase Required
Copy code save10
Copied
Free delivery by Sep 26 on orders $50+·Delivery by Sep 26 $7.99
·30-day returns
Mercato.com
$13.59
Aspercreme Pain Relief Liquid, Roll-On, Max Strength, Fragrance Free - 2.5 Fluid Ounces - Vashon Thriftway - Delivered by Mercato
Out of stock online
4.5/5
·Delivery by Mon on orders $35+
·30-day returns
Rite Aid
$12.49
Aspercreme Lidocaine Pain Relief Roll-On - 2.5 oz
Out of stock online
4.7/5
·Delivery $6.99
·90-day returns